import click

def main():
    pass

@click.command()
@click.argument('text')
def dream(text):
    return 'not ready yet'
